from setuptools import setup

setup(name='dsnd_probability_yrmadev',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['dsnd_probability_yrmadev'],
      author = 'Yrma Dev',
      author_email = 'yrmadev@outlook.com',
      zip_safe=False)
